==> sci_mobile_components-1.0.1.tar.gz: lib/src/components/SCITempChart.dart <==
import 'package:fl_chart/fl_chart.dart';
import 'package:flutter/material.dart';
import 'package:sci_mobile_components/src/models/vital_sign.dart';

class SCITempChart extends StatelessWidget {
  final List<VitalSignData> temperature;

  SCITempChart({@required this.temperature});

  @override
  Widget build(BuildContext context) {
    return Column(
      children: <Widget>[
        Container(
          width: double.infinity,
          height: 200.0,
          child: LineChart(
            LineChartData(
              maxX: temperature.length.toDouble() + 1,
              clipToBorder: false,
              gridData: FlGridData(horizontalInterval: 10.0),
              lineTouchData: LineTouchData(enabled: false),
              axisTitleData: FlAxisTitleData(
                show: true,
                topTitle: AxisTitle(
                  showTitle: true,
                  titleText: 'Temperature',
                  textStyle: Theme.of(context).textTheme.headline,
                ),
              ),
              titlesData: FlTitlesData(
                bottomTitles: SideTitles(showTitles: false),
                leftTitles: SideTitles(
                  showTitles: true,
                  interval: 10.0,
                  margin: 10.0,
                  textStyle: Theme.of(context)
                      .textTheme
                      .caption
                      .copyWith(fontWeight: FontWeight.bold),
                  getTitles: (i) => '${i.toInt()}',
                ),
              ),
              borderData: FlBorderData(
                show: true,
                border: Border.all(
                  color: Colors.blue,
                  width: 3.0,
                ),
              ),
              minY: 0,
              maxY: 100,
              lineBarsData: [
                /// Temperature
                LineChartBarData(
                  dotData: FlDotData(dotColor: Colors.redAccent),
                  show: true,
                  barWidth: 2.0,
                  spots: temperature
                      .map(
                        (s) => FlSpot(
                          s.createdDate.day.toDouble(),
                          double.parse(s.value),
                        ),
                      )
                      .toList(),
                ),
              ],
            ),
          ),
        ),
        SizedBox(height: 10.0),

        /// Legend
        Row(
          mainAxisAlignment: MainAxisAlignment.center,
          children: <Widget>[
            Spacer(flex: 3),
            Text(
              'Temperature',
              style: Theme.of(context).textTheme.body2,
            ),
            Spacer(),
            Container(
              height: 10.0,
              width: 10.0,
              color: Colors.redAccent,
            ),
            Spacer(flex: 3)
          ],
        )
      ],
    );
  }
}

==> sci_mobile_components-1.0.3.tar.gz: lib/src/components/SCITempChart.dart <==
import 'package:fl_chart/fl_chart.dart';
import 'package:flutter/material.dart';
import 'package:sci_mobile_components/src/models/vital_sign.dart';

class SCITempChart extends StatelessWidget {
  final List<VitalSignData> temperature;

  SCITempChart({@required this.temperature});

  @override
  Widget build(BuildContext context) {
    return Column(
      children: <Widget>[
        Container(
          width: double.infinity,
          height: 200.0,
          child: LineChart(
            LineChartData(
              minX: temperature.first.createdDate.day.toDouble() - 0.25,
              maxX: temperature.last.createdDate.day.toDouble() + 1,
              minY: 0,
              maxY: 100,
              clipToBorder: false,
              gridData: FlGridData(horizontalInterval: 10.0),
              lineTouchData: LineTouchData(enabled: false),
              axisTitleData: FlAxisTitleData(
                show: true,
                topTitle: AxisTitle(
                  showTitle: true,
                  titleText: 'Temperature',
                  textStyle: Theme.of(context).textTheme.headline,
                ),
              ),
              titlesData: FlTitlesData(
                bottomTitles: SideTitles(showTitles: false),
                leftTitles: SideTitles(
                  showTitles: true,
                  interval: 10.0,
                  margin: 10.0,
                  textStyle: Theme.of(context)
                      .textTheme
                      .caption
                      .copyWith(fontWeight: FontWeight.bold),
                  getTitles: (i) => '${i.toInt()}',
                ),
              ),
              borderData: FlBorderData(
                show: true,
                border: Border.all(
                  color: Colors.blue,
                  width: 3.0,
                ),
              ),
              lineBarsData: [
                /// Temperature
                LineChartBarData(
                  dotData: FlDotData(dotColor: Colors.redAccent),
                  show: true,
                  barWidth: 2.0,
                  spots: temperature.map((s) {
                    print(s.createdDate.day);
                    return FlSpot(
                      s.createdDate.day.toDouble(),
                      double.parse(s.value),
                    );
                  }).toList(),
                ),
              ],
            ),
          ),
        ),
        SizedBox(height: 10.0),

        /// Legend
        Row(
          mainAxisAlignment: MainAxisAlignment.center,
          children: <Widget>[
            Spacer(flex: 3),
            Text(
              'Temperature',
              style: Theme.of(context).textTheme.body2,
            ),
            Spacer(),
            Container(
              height: 10.0,
              width: 10.0,
              color: Colors.redAccent,
            ),
            Spacer(flex: 3)
          ],
        )
      ],
    );
  }
}
